<!-- Optionally -->
Fixes #

#### Description


#### Checklist
<!-- If an item is not relevant, leave it unchecked -->
- [ ] `make pre-commit` succeeds
- [ ] `make coverage` shows that new code is covered with tests
- [ ] docstrings are updated
- [ ] `__all__` lists are updated
- [ ] docs/reference/*.rst are updated
